HickoryResolver

Struct HickoryResolver 

pub struct HickoryResolver { /* private fields */ }
A DNS resolver for hyper based on hickory.

Implementations

Source

impl HickoryResolver

pub fn from_system_conf() -> Result<Self, GenericError>

Creates a new HickoryResolver based on the system’s resolver configuration.

Panics

This will panic if called outside the context of a Tokio runtime.

Errors

If there is an issue loading the system configuration, an error is returned.

pub fn noop() -> Self

Creates a placeholder HickoryResolver with no configured nameservers.

This resolver will never successfully resolve any names. It exists solely as a placeholder for code paths where DNS resolution is never needed (for example, vsock transport), avoiding initialization failures in environments without system DNS configuration such as Nitro Enclaves.

pub fn with_lookup_errors_counter(self, counter: Counter) -> Self

Sets a counter that’s incremented when DNS lookup fails.

pub fn into_http_connector(self) -> HickoryHttpConnector

Consumes self and creates a new HickoryHttpConnector with this resolver.