pub struct SystemResolver { /* private fields */ }Expand description
A DNS resolver for hyper backed by the operating system resolver.
Lookups are handled in the default Tokio blocking thread pool as calls to getaddrinfo are synchronous.
Implementations
Sourceimpl SystemResolver
impl SystemResolver
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new SystemResolver.
Sourcepub fn with_lookup_errors_counter(self, counter: Counter) -> Self
pub fn with_lookup_errors_counter(self, counter: Counter) -> Self
Sets a counter that’s incremented when DNS lookup fails.
Sourcepub fn into_http_connector(self) -> SystemHttpConnector
pub fn into_http_connector(self) -> SystemHttpConnector
Consumes self and creates a new SystemHttpConnector with this resolver.