pub struct HickoryResolver { /* private fields */ }Expand description
A DNS resolver for hyper based on hickory.
Implementations
Sourceimpl HickoryResolver
impl HickoryResolver
Sourcepub fn from_system_conf() -> Result<Self, GenericError>
pub fn from_system_conf() -> Result<Self, GenericError>
Creates a new HickoryResolver based on the system’s resolver configuration.
Panics
This will panic if called outside the context of a Tokio runtime.
Errors
If there is an issue loading the system configuration, an error is returned.
Sourcepub fn into_http_connector(self) -> HickoryHttpConnector
pub fn into_http_connector(self) -> HickoryHttpConnector
Consumes self and creates a new HickoryHttpConnector with this resolver.